package com.ynet.life.html;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEConstance;
import com.ynet.gene.core.GENEException;
import com.ynet.gene.data.IndexedCollection;
import com.ynet.gene.data.KeyedCollection;
import com.ynet.gene.session.Session;
import com.ynet.gene.session.SessionManager;
import com.ynet.life.base.LifeAppParam;
import com.ynet.life.base.LifeConstants;
import com.ynet.life.base.LifeErrorInfo;
import com.ynet.life.base.LifeStandard;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.format.LifeFormat;
import com.ynet.life.format.LifeStringFilter;
import com.ynet.life.platform.util.PlatformUtil;
import java.math.BigDecimal;
import java.text.DecimalFormat;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Map;
import java.util.Set;
import java.util.StringTokenizer;
import java.util.Vector;
import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/* loaded from: com_ynet_life_html.jar:com/ynet/life/html/LifeJspContextServices.class */
public class LifeJspContextServices {
    public static final String LOG_ID = "LifeHTML";
    private static final String URL_SEPERATOR = "/";
    private static final TranFailException EXCEPTION_SESSION_TIMEOUT = new TranFailException("EBLN0000", "session timeout", false);
    private static final TranFailException EXCEPTION_CONTEXT_NOT_FOUND = new TranFailException("EBLN0000", "无法获得Context");
    private Context itsContext;
    private Context itsSessionContext;
    private String itsWebContext;
    private HttpServletRequest itsRequest;

    public void initialize(HttpServletRequest request, HttpServletResponse response) throws TranFailException {
        this.itsRequest = request;
        this.itsWebContext = String.valueOf(request.getContextPath()) + URL_SEPERATOR;
        if (request.getContextPath().equals(URL_SEPERATOR)) {
            this.itsWebContext = request.getContextPath();
        }
        Context context = (Context) request.getAttribute(GENEConstance.ATTR_CONTEXT);
        if (context == null) {
            log(EXCEPTION_CONTEXT_NOT_FOUND);
            throw EXCEPTION_CONTEXT_NOT_FOUND;
        }
        this.itsContext = context;
        if (context.getName().endsWith("SessionCtx")) {
            this.itsSessionContext = context;
        } else {
            this.itsSessionContext = context.getParent();
            String enableFilter = request.getParameter("enableScriptFilter");
            if (!"false".equalsIgnoreCase(enableFilter) && enableFilter()) {
                LifeStringFilter.filterHtmlTagFromKeyedCollection(this.itsContext.getDataElement());
            }
        }
        if (this.itsSessionContext == null) {
            Trace.logWarning("LifeAction", "Session超时");
            throw EXCEPTION_SESSION_TIMEOUT;
        }
        ServletContext servletContext = request.getSession().getServletContext();
        servletContext.setAttribute("appParams", LifeStandard.getAppParams(getLanguage()));
        servletContext.setAttribute("sysParams", LifeStandard.getSystemParams());
        servletContext.setAttribute("settings", LifeStandard.getSelfDefineSettings());
    }

    public void initializeNoSession(HttpServletRequest request, HttpServletResponse response) throws TranFailException {
        this.itsRequest = request;
        this.itsWebContext = String.valueOf(request.getContextPath()) + URL_SEPERATOR;
        Context context = (Context) request.getAttribute(GENEConstance.ATTR_CONTEXT);
        if (context != null) {
            this.itsContext = context;
            if (enableFilter()) {
                LifeStringFilter.filterHtmlTagFromKeyedCollection(this.itsContext.getDataElement());
            }
        }
    }

    private boolean enableFilter() {
        return Boolean.valueOf(LifeStandard.getSelfDefineSettingsValue("enableScriptFilter")).booleanValue();
    }

    public String get(String key) {
        String parameter = this.itsRequest.getParameter(key);
        String value = parameter;
        if (parameter != null && enableFilter()) {
            value = LifeStringFilter.filterHtmlTag(value);
        }
        return value;
    }

    public String getDisplayAt(String value) {
        String language;
        try {
            language = getLanguage();
        } catch (Exception unused) {
            language = "ZH_CN";
        }
        return LifeStandard.getResouceDisplayAt(value, language);
    }

    public String getDisplayAt(String appCode, String appValue) {
        String language;
        try {
            language = getLanguage();
        } catch (Exception unused) {
            language = "ZH_CN";
        }
        if (language == null) {
            language = "ZH_CN";
        }
        return getDisplayAt(appCode, appValue, language);
    }

    public String getDisplayAt(String appCode, String appValue, String displayLanguage) {
        return LifeStandard.getAppDisplay(appCode, appValue, displayLanguage);
    }

    public String getErrorDisplay(String errorCode) {
        String language;
        try {
            language = getLanguage();
        } catch (Exception unused) {
            language = "ZH_CN";
        }
        return getErrorDisplay(errorCode, language);
    }

    public String getErrorDisplay(String errorCode, String displayLanguage) {
        LifeErrorInfo error = LifeStandard.getErrorInfo(errorCode, displayLanguage);
        if (error == null) {
            return errorCode;
        }
        return error.getShowMsg();
    }

    public String getFormatNumber(String number, String format) {
        return new DecimalFormat(format).format(new BigDecimal(number).floatValue());
    }

    public String getServerDate(String inputFormat) {
        return LifeStandard.getServerTime(inputFormat);
    }

    public String getSelectOpt(Map map) {
        StringBuffer result = new StringBuffer();
        for (String key : map.keySet()) {
            result.append("<option value='" + key + "'>" + ((String) map.get(key)) + "</option>\n");
        }
        return result.toString();
    }

    public String getSelectOpt(IndexedCollection aIColl, String aKCollKeyName, String aKCollValueName) {
        StringBuffer result = new StringBuffer();
        int size = aIColl.size();
        for (int i = 0; i < size; i++) {
            try {
                KeyedCollection kColl = aIColl.getElementAt(i);
                String currentKey = (String) kColl.getDataValue(aKCollKeyName);
                String currentValue = (String) kColl.getDataValue(aKCollValueName);
                result.append("<option value='" + currentKey + "'>" + currentValue + "</option>");
            } catch (GENEException unused) {
                return "<option value=''>option error</option>";
            }
        }
        return result.toString();
    }

    public String getSelectOpt(IndexedCollection aIColl, String aKCollKeyName, String aKCollValueName, String selectValue) {
        StringBuffer result = new StringBuffer();
        int size = aIColl.size();
        for (int i = 0; i < size; i++) {
            try {
                KeyedCollection kColl = aIColl.getElementAt(i);
                String[] keyName = aKCollKeyName.split("\\|");
                String currentKey = "";
                for (String str : keyName) {
                    currentKey = String.valueOf(currentKey) + "|" + ((String) kColl.getDataValue(str));
                }
                String currentKey2 = currentKey.substring(1);
                String currentValue = (String) kColl.getDataValue(aKCollValueName);
                if (selectValue != null && selectValue.length() > 0 && currentKey2.indexOf(selectValue) >= 0) {
                    result.append("<option value=\"" + currentKey2 + "\" selected>" + currentValue + "</option>");
                } else {
                    result.append("<option value=\"" + currentKey2 + "\">" + currentValue + "</option>");
                }
            } catch (GENEException unused) {
                return "<option value=\"\">option error</option>";
            }
        }
        return result.toString();
    }

    public String getSelectOpt(String appCode) {
        return getSelectOpt(appCode, "");
    }

    public String getSelectOptAndValue(String appCode) {
        return getSelectOptAndValue(appCode, "");
    }

    public String getSelectOptAndValue(String appCode, String appValue) {
        String language;
        try {
            language = getLanguage();
        } catch (Exception unused) {
            language = "ZH_CN";
        }
        if (language == null) {
            language = "ZH_CN";
        }
        return getSelectOptAndValue(appCode, appValue, language, true);
    }

    public String getSelectOptAndValue(String appCode, String appValue, String displayLanguage, boolean sortFlag) {
        StringBuffer buffer = new StringBuffer("");
        Map map = LifeStandard.getAppCodeHash(appCode, displayLanguage);
        if (map != null) {
            Vector sortVector = new Vector();
            Iterator iterator = map.keySet().iterator();
            while (iterator.hasNext()) {
                String currentValue = ((LifeAppParam) map.get(iterator.next())).getValue();
                sortVector.add(currentValue);
            }
            if (sortFlag) {
                Collections.sort(sortVector);
            }
            for (int i = 0; i < sortVector.size(); i++) {
                String value = (String) sortVector.elementAt(i);
                String message = ((LifeAppParam) map.get(value)).getShowMessage();
                if (value.equals(appValue)) {
                    buffer.append("<option value=\"").append(value).append("\" selected>");
                    buffer.append(value);
                    buffer.append("-");
                    buffer.append(message);
                    buffer.append("</option>");
                } else {
                    buffer.append("<option value=\"").append(value).append("\">");
                    buffer.append(value);
                    buffer.append("-");
                    buffer.append(message);
                    buffer.append("</option>");
                }
            }
        }
        return buffer.toString();
    }

    public String getSelectOpt(String appCode, String appValue) {
        String language;
        try {
            language = getLanguage();
        } catch (Exception unused) {
            language = "ZH_CN";
        }
        if (language == null) {
            language = "ZH_CN";
        }
        return getSelectOpt(appCode, appValue, language, true);
    }

    public String getSelectOpt(String appCode, String appValue, boolean sortFlag) {
        String language;
        try {
            language = getLanguage();
        } catch (Exception unused) {
            language = "ZH_CN";
        }
        if (language == null) {
            language = "ZH_CN";
        }
        return getSelectOpt(appCode, appValue, language, sortFlag);
    }

    public String getSelectOpt(String appCode, String appValue, String displayLanguage, boolean sortFlag) {
        StringBuffer buffer = new StringBuffer("");
        Map map = LifeStandard.getAppCodeHash(appCode, displayLanguage);
        if (map != null) {
            Vector sortVector = new Vector();
            Iterator iterator = map.keySet().iterator();
            while (iterator.hasNext()) {
                String currentValue = ((LifeAppParam) map.get(iterator.next())).getValue();
                sortVector.add(currentValue);
            }
            if (sortFlag) {
                Collections.sort(sortVector);
            }
            for (int i = 0; i < sortVector.size(); i++) {
                String value = (String) sortVector.elementAt(i);
                String message = ((LifeAppParam) map.get(value)).getShowMessage();
                if (value.equals(appValue)) {
                    buffer.append("<option value=\"").append(value).append("\" selected>");
                    buffer.append(message);
                    buffer.append("</option>");
                } else {
                    buffer.append("<option value=\"").append(value).append("\">");
                    buffer.append(message);
                    buffer.append("</option>");
                }
            }
        }
        return buffer.toString();
    }

    public String getSelectOpt(String appCode, String appValue, String displayLanguage, String delValueList) {
        StringBuffer buffer = new StringBuffer("");
        if (displayLanguage == null || "".equals(displayLanguage)) {
            try {
                displayLanguage = getLanguage();
            } catch (Exception unused) {
                displayLanguage = "ZH_CN";
            }
            if (displayLanguage == null) {
                displayLanguage = "ZH_CN";
            }
        }
        Map map = LifeStandard.getAppCodeHash(appCode, displayLanguage);
        if (map != null) {
            Vector sortVector = new Vector();
            Iterator iterator = map.keySet().iterator();
            while (iterator.hasNext()) {
                String currentValue = ((LifeAppParam) map.get(iterator.next())).getValue();
                if (delValueList.indexOf(currentValue) == -1) {
                    sortVector.add(currentValue);
                }
            }
            Collections.sort(sortVector);
            for (int i = 0; i < sortVector.size(); i++) {
                String value = (String) sortVector.elementAt(i);
                String message = ((LifeAppParam) map.get(value)).getShowMessage();
                if (value.equals(appValue)) {
                    buffer.append("<option value=\"").append(value).append("\" selected>");
                    buffer.append(message);
                    buffer.append("</option>");
                } else {
                    buffer.append("<option value=\"").append(value).append("\">");
                    buffer.append(message);
                    buffer.append("</option>");
                }
            }
        }
        return buffer.toString();
    }

    public Set getHashSetFromIcoll(String iCollName, String keyName) {
        Set result = new HashSet();
        try {
            IndexedCollection iColl = getContext().getDataElement(iCollName);
            int size = iColl.size();
            for (int i = 0; i < size; i++) {
                try {
                    String key = (String) iColl.getElementAt(i).getDataValue(keyName);
                    result.add(key);
                } catch (GENEException ex) {
                    log(ex);
                }
            }
            return result;
        } catch (GENEException unused) {
            return result;
        }
    }

    public Map getHashFromIcoll(String iCollName, String keyName, String valueName) {
        Map result = new HashMap();
        try {
            IndexedCollection iColl = getContext().getDataElement(iCollName);
            int size = iColl.size();
            for (int i = 0; i < size; i++) {
                KeyedCollection kColl = iColl.getElementAt(i);
                String key = "";
                StringTokenizer st = new StringTokenizer(keyName, "|");
                while (st.hasMoreTokens()) {
                    key = String.valueOf(key) + ((String) kColl.get(st.nextToken()));
                }
                String value = (String) kColl.get(valueName);
                result.put(key, value);
            }
            return result;
        } catch (GENEException unused) {
            return result;
        }
    }

    public Context getContext() {
        return this.itsContext;
    }

    public Context getSessionContext() {
        return this.itsSessionContext;
    }

    public String getWebAppPath() {
        return this.itsWebContext;
    }

    public String nvl(Object dataValue) {
        return nvl(dataValue, "");
    }

    public String nvl(Object dataValue, String returnValue) {
        return LifeFormat.nvl(dataValue, returnValue);
    }

    protected void log(Exception ex) {
        Trace.logError(LOG_ID, "页面异常", ex);
    }

    public String getFmtCurrency(String currency) {
        return LifeFormat.formatCurrency(currency);
    }

    public String getFmtDate(String date) {
        return LifeFormat.formatDate(date, "yyyy-MM-dd");
    }

    public String getFmtDate(String date, String format) {
        return LifeFormat.formatDate(date, format);
    }

    public String getChineseCurrency(String money) {
        return LifeFormat.formatChineseCurrency(money);
    }

    public String getDifferentDate(int days, String timeFormat) {
        return LifeFormat.getDifferentDate(days, timeFormat);
    }

    public String getDifferentTime(int hour, int minute, int second, String timeFormat) {
        return LifeFormat.getDifferentTime(hour, minute, second, timeFormat);
    }

    public String getRequiredHtmlFields(boolean controlSubmit) {
        StringBuffer result = new StringBuffer();
        SessionManager sessionManager = (SessionManager) this.itsRequest.getAttribute(GENEConstance.ATTR_SESSION_MGR);
        result.append(sessionManager.getAppendPostField(this.itsRequest, LOG_ID));
        if (controlSubmit) {
            result.append("<input type=\"hidden\" name=\"").append(LifeConstants.FIELD_SUBMIT_TIMESTAMP);
            result.append("\" value=\"").append(LifeStandard.getServerTime((String) null)).append("\">");
        }
        return result.toString();
    }

    public String getConfirmFields(HttpServletRequest request) {
        Set filterSet = new HashSet();
        filterSet.add(LifeConstants.FIELD_SUBMIT_TIMESTAMP);
        filterSet.add(GENEConstance.GENE_SESSION_ID_LABEL);
        return getConfirmFields(request, filterSet);
    }

    public String getConfirmFields(HttpServletRequest request, Set filterSet) {
        Map map = request.getParameterMap();
        StringBuffer sb = new StringBuffer();
        for (Map.Entry element : map.entrySet()) {
            String paramName = (String) element.getKey();
            if (!filterSet.contains(paramName)) {
                String[] valueArray = (String[]) element.getValue();
                for (String str : valueArray) {
                    sb.append("<input type=\"hidden\" name=\"").append(paramName);
                    sb.append("\" value=\"").append(str).append("\">\n");
                }
            }
        }
        return sb.toString();
    }

    public String getURL(String url) {
        return ((SessionManager) this.itsRequest.getAttribute(GENEConstance.ATTR_SESSION_MGR)).encodeURL(this.itsRequest, (HttpServletResponse) null, url, (String) null);
    }

    public String getSessionId() {
        this.itsRequest.getAttribute(GENEConstance.ATTR_SESSION_MGR);
        return ((Session) this.itsRequest.getAttribute(GENEConstance.ATTR_SESSION)).getId();
    }

    public String showInputError() {
        String result = (String) this.itsRequest.getAttribute("GENE_INPUTERROR");
        if (result == null) {
            return "";
        }
        this.itsRequest.removeAttribute("GENE_INPUTERROR");
        return result;
    }

    public String getLanguage() {
        try {
            String language = (String) getSessionContext().getDataValue("session_language");
            if (language == null) {
                return "zh_cn";
            }
            return language;
        } catch (Exception unused) {
            return "zh_cn";
        }
    }

    public String getLastMonthDay(String format) {
        Calendar now = Calendar.getInstance();
        now.add(2, -1);
        return new SimpleDateFormat(format).format(now.getTime());
    }

    public String getServiceDay(String format, int dayType, int interval) {
        Calendar now = Calendar.getInstance();
        switch (dayType) {
            case 1:
                now.add(1, interval);
                break;
            case 2:
                now.add(2, interval);
                break;
            case 3:
            case 4:
            default:
                now.add(5, interval);
                break;
            case 5:
                now.add(5, interval);
                break;
        }
        return new SimpleDateFormat(format).format(now.getTime());
    }

    public String getSelectCheckBox(String appCode, String formName) {
        return getSelectCheckBox(appCode, formName, new String[0]);
    }

    public String getSelectCheckBox(String appCode, String formName, String[] appValue) {
        String language;
        try {
            language = getLanguage();
        } catch (Exception unused) {
            language = "ZH_CN";
        }
        if (language == null) {
            language = "ZH_CN";
        }
        Map map = LifeStandard.getAppCodeHash(appCode, language);
        Map map1 = new HashMap();
        Iterator iterator = map.keySet().iterator();
        while (iterator.hasNext()) {
            LifeAppParam param = (LifeAppParam) map.get(iterator.next());
            map1.put(param.getValue(), param.getShowMessage());
        }
        return getSelectCheckBox(map1, formName, appValue);
    }

    public String getSelectCheckBox(Map map, String formName, String[] appValue) {
        StringBuffer buffer = new StringBuffer("");
        if (map != null) {
            new Vector();
            for (String currentValue : map.keySet()) {
                String showValue = (String) map.get(currentValue);
                if (inArray(appValue, currentValue)) {
                    buffer.append("<input type='checkbox' name='" + formName + "' value='" + currentValue + "' checked/>" + showValue + "&nbsp;");
                } else {
                    buffer.append("<input type='checkbox' name='" + formName + "' value='" + currentValue + "'/>" + showValue + "&nbsp;");
                }
            }
        }
        return buffer.toString();
    }

    private boolean inArray(String[] values, String value) {
        boolean flag = false;
        if (values != null) {
            int i = 0;
            while (true) {
                if (i >= values.length) {
                    break;
                }
                if (values[i] == null || !values[i].equals(value)) {
                    i++;
                } else {
                    flag = true;
                    break;
                }
            }
        }
        return flag;
    }

    public String getDisplayAt(IndexedCollection icoll, String code, String value) {
        String str = "";
        for (int i = 0; i < icoll.size(); i++) {
            KeyedCollection kcoll = icoll.getElementAt(i);
            String appCode = (String) kcoll.get("parCode");
            String appValue = (String) kcoll.get("parValue");
            str = (String) kcoll.get("parShowMsg");
            if (appCode.equals(code) && appValue.equals(value)) {
                break;
            }
        }
        return str;
    }

    public String getDisplayAt(IndexedCollection icoll, String keyName, String valueName, String value) {
        String str = "";
        for (int i = 0; i < icoll.size(); i++) {
            KeyedCollection kcoll = icoll.getElementAt(i);
            String appCode = (String) kcoll.get(keyName);
            str = (String) kcoll.get(valueName);
            if (appCode.equals(value)) {
                break;
            }
        }
        return str;
    }

    public Map icollToMap(IndexedCollection icoll, String keyName, String valueName) {
        Map map = new HashMap();
        for (int i = 0; i < icoll.size(); i++) {
            KeyedCollection kcoll = icoll.getElementAt(i);
            map.put(kcoll.get(keyName), kcoll.get(valueName));
        }
        return map;
    }

    public String[] getArrayFromIColl(IndexedCollection icoll, String key) {
        String[] values = new String[icoll.size()];
        for (int i = 0; i < icoll.size(); i++) {
            KeyedCollection kcoll = icoll.getElementAt(i);
            values[i] = (String) kcoll.get(key);
        }
        return values;
    }

    public String getCustomerName(IndexedCollection customerRoleList, String customerRoleNo) {
        String returnValue = customerRoleNo;
        if (customerRoleList != null && customerRoleList.size() > 0) {
            for (int i = 0; i < customerRoleList.size(); i++) {
                KeyedCollection kcoll = customerRoleList.getElementAt(i);
                String cusNo = (String) kcoll.get("customerRoleNo");
                String cusName = (String) kcoll.get("customerRoleName");
                if (cusNo.equals(customerRoleNo)) {
                    returnValue = cusName;
                }
            }
        }
        return returnValue;
    }

    public String getAppName(String key, String language) {
        return LifeStandard.getAppName(key, language);
    }

    public String getSelectOpt(String appCode, String appValue, String displayLanguage) {
        StringBuffer buffer = new StringBuffer("");
        Map map = LifeStandard.getAppCodeHash(appCode, displayLanguage);
        if (map != null) {
            Vector sortVector = new Vector();
            Iterator iterator = map.keySet().iterator();
            while (iterator.hasNext()) {
                String currentValue = ((LifeAppParam) map.get(iterator.next())).getValue();
                sortVector.add(currentValue);
            }
            Collections.sort(sortVector);
            for (int i = 0; i < sortVector.size(); i++) {
                String value = (String) sortVector.elementAt(i);
                String message = ((LifeAppParam) map.get(value)).getShowMessage();
                if (value.equals(appValue)) {
                    buffer.append("<option value=\"").append(value).append("\" selected>");
                    buffer.append(message);
                    buffer.append("</option>");
                } else {
                    buffer.append("<option value=\"").append(value).append("\">");
                    buffer.append(message);
                    buffer.append("</option>");
                }
            }
        }
        return buffer.toString();
    }

    public String getBankId() {
        String bankId;
        String[] arr = LifeStandard.getSelfDefineSettingsValue("CurrentBankId").split(",");
        String product = arr[0];
        String manyBank = arr[1];
        if (product.equals("false")) {
            bankId = arr[2];
        } else if (manyBank.equals("false")) {
            bankId = arr[2];
        } else {
            bankId = PlatformUtil.getBankIdByRequest(this.itsRequest);
        }
        return bankId;
    }
}
